/******************************************************************************
* C Source: Header_List                                                       *
*                                                                             *
* File:                                                                       *
*    hdrlist.c                                                                *
*                                                                             *
* Description:                                                                *
*    This set of functions performs various manipulations on a linked list    *
*    (see lnkd_lst.c and lnkd_lst.h) of plate Headers (see header.c and       *
*    header.h), each node for an individual plate. (see header.h).            *
*                                                                             *
* Module List:                                                                *
*    Add_Header_to_List                                                       *
*       Insert a header into the top of a header list.                        *
*    Create_Empty_Header_List                                                 *
*       Create a new empty header list.                                       *
*    Delete_Header_List_Data                                                  *
*       Delete the linked list for a header list, AND the header data the     *
*       list points to.                                                       *
*    Get_Header_from_List                                                     *
*       Get header from list matching input plate id.                         *
*                                                                             *
* History:                                                                    *
*    Created    : 23-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#include "hdrlist.h"

#include "generic.h"
#include "header.h"
#include "lnkd_lst.h"

/******************************************************************************
* Module:                                                                     *
*    Add_Header_to_List                                                       *
*                                                                             *
* File:                                                                       *
*    hdrlist.c                                                                *
*                                                                             *
* Description:                                                                *
*    Adds a header to the top of a header list.                               *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          HDR_LIST, Reference                                                *
*             The header list to which we're adding the header.               *
*       Header                                                                *
*          HEADER, Reference                                                  *
*             The header we're adding to the header list.                     *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 23-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**********************************
* Add_Header_to_List declarations *
**********************************/
void     Add_Header_to_List( List, Header )
HDR_LIST List  ;
HEADER   Header;
{
/*******************************************
* Add_Header_to_List begin executable code *
*******************************************/
   Insert_Linked_List_Data( List, Header );

   return;
}
/*****************************************
* Add_Header_to_List end executable code *
*****************************************/

/******************************************************************************
* Module:                                                                     *
*    Create_Empty_Header_List                                                 *
*                                                                             *
* File:                                                                       *
*    hdrlist.c                                                                *
*                                                                             *
* Description:                                                                *
*    Create a new empty header list, allocating memory for the linked list    *
*    header.                                                                  *
*                                                                             *
* Return Value:                                                               *
*    HDR_LIST: The newly created plate.                                       *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       none                                                                  *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 23-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/****************************************
* Create_Empty_Header_List declarations *
****************************************/
HDR_LIST Create_Empty_Header_List()
{
/*************************************************
* Create_Empty_Header_List begin executable code *
*************************************************/
   return ( HDR_LIST )Create_Empty_Linked_List();

}
/***********************************************
* Create_Empty_Header_List end executable code *
***********************************************/

/******************************************************************************
* Module:                                                                     *
*    Delete_Header_List_Data                                                  *
*                                                                             *
* File:                                                                       *
*    hdrlist.c                                                                *
*                                                                             *
* Description:                                                                *
*    Free memory allocated for header list, but AND the data it points to.    *
*                                                                             *
* Return Value:                                                               *
*    none                                                                     *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          HDR_LIST, Reference                                                *
*             The header list we're deleting from memory.                     *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 17-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/***************************************
* Delete_Header_List_Data declarations *
***************************************/
void      Delete_Header_List_Data( List )
HDR_LIST List;
{
/************************************************
* Delete_Header_List_Data begin executable code *
************************************************/
   Delete_Linked_List_Data( List, Delete_Header );

   return;
}
/**********************************************
* Delete_Header_List_Data end executable code *
**********************************************/

/******************************************************************************
* Module:                                                                     *
*    Get_Header_from_List                                                     *
*                                                                             *
* File:                                                                       *
*    hdrlist.c                                                                *
*                                                                             *
* History:                                                                    *
*    Created    : 23-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Description:                                                                *
*    Get header from list matching input plate id.                            *
*                                                                             *
* Return Value:                                                               *
*    HEADE: Header we matched to input plate id.                              *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       List                                                                  *
*          HDR_LIST, Reference                                                *
*             List we're searching for plate id.                              *
*       Plate_Id                                                              *
*          STRING, Reference                                                  *
*             Plate we're searching for.                                      *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 23-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/************************************
* Get_Header_from_List declarations *
************************************/
HEADER   Get_Header_from_List( List, Plate_Id )
HDR_LIST List    ;
STRING   Plate_Id;
{
/*********************************************
* Get_Header_from_List begin executable code *
*********************************************/
   return ( HEADER )Find_Linked_List_Data
                                     ( List, Plate_Id, Check_Header_Plate_Id );
}
/*******************************************
* Get_Header_from_List end executable code *
*******************************************/

